@@ -2,7 +2,7 @@ OC.L10N.register(
     "calendar",
     {
     "User-Session unexpectedly expired" : "نشست کاربر به طور غیر منتظره منقضی شد",
-    "Provided email-address is not valid" : "آدرس ایمیل ارائه شده معتبر نیست",
+    "Provided email-address is not valid" : "ایمیل ارائه شده معتبر نیست",
     "%s has published the calendar »%s«" : "%sتقویم %s را منتشر کرده است.",
     "Unexpected error sending email. Please contact your administrator." : "خطای غیر منتظره در ارسال ایمیل. لطفا با مدیر خود تماس بگیرید.",
     "Hello," : "سلام،",
@@ -12,8 +12,10 @@ OC.L10N.register(
     "Upcoming events" : "رویدادهای پیش‌رو",
     "Appointments" : "قرارها",
     "Confirm" : "تائید",
+    "Appointment:" : "قرار ملاقات:",
     "Date:" : "تاریخ:",
     "Where:" : "مکان:",
+    "Description:" : "توضیحات:",
     "Calendar" : "تقویم",
     "A Calendar app for Nextcloud" : "یک برنامه تقویم برای نکست کلود",
     "Previous day" : "روز قبل",
@@ -32,13 +34,14 @@ OC.L10N.register(
     "Copy link" : "کپی کردن لینک",
     "Edit" : "ویرایش",
     "Delete" : "حذف",
+    "Add new" : "افزودن مورد تازه",
     "Untitled calendar" : "تقویم بدون عنوان",
     "Edit name" : "ویرایش نام",
     "Saving name …" : "ذخیره نام",
     "Edit color" : "ویرایش رنگ",
     "Saving color …" : "ذخیره رنگ",
     "Copy private link" : "کپی کردن پیوند خصوصی",
-    "Export" : "گرفتن خروجی",
+    "Export" : "دریافت خروجی",
     "Unshare from me" : "بی خبر از من",
     "An error occurred, unable to change visibility of the calendar." : "خطایی روی داد ، قادر به تغییر دیدگاه تقویم نیست.",
     "An error occurred, unable to delete the calendar." : "خطایی روی داد ، قادر به حذف تقویم نیست.",
@@ -76,7 +79,6 @@ OC.L10N.register(
     "Unshare with {displayName}" : "عدم اشتراک گذاری با {displayName}",
     "An error occurred, unable to change the unshare the calendar." : "خطایی روی داد ، قادر به تغییر تقویم عدم اشتراک گذاری نیست.",
     "An error occurred, unable to change the permission of the share." : "خطایی روی داد ، قادر به تغییر مجوز اشتراک نیست.",
-    "+ New calendar" : "+ تقویم جدید",
     "New calendar" : "تقویم جدید",
     "Creating calendar …" : "ایجاد تقویم ...",
     "New calendar with task list" : "تقویم جدید با لیست کارها",
@@ -100,6 +102,7 @@ OC.L10N.register(
     "Automatic" : "خودکار",
     "Automatic ({detected})" : "خودکار ({شناسایی})",
     "New setting was not saved successfully." : "تنظیم جدید با موفقیت ذخیره نشد.",
+    "or" : "یا",
     "List view" : "نمایش لیست",
     "Actions" : "فعالیت ها",
     "Enable birthday calendar" : "تقویم تولد را فعال کنید",
@@ -108,6 +111,7 @@ OC.L10N.register(
     "Show week numbers" : "نمایش شماره های هفته",
     "Copy primary CalDAV address" : "آدرس اصلی CalDAV را کپی کنید",
     "Copy iOS/macOS CalDAV address" : "آدرس CalDAV iOS / macOS را کپی کنید",
+    "Calendar settings" : "تنظیمات تقویم",
     "CalDAV link copied to clipboard." : "پیوند CalDAV در کلیپ بورد کپی شد.",
     "CalDAV link could not be copied to clipboard." : "پیوند CalDAV در کلیپ بورد قابل کپی نیست.",
     "Location" : "محل",
@@ -211,6 +215,9 @@ OC.L10N.register(
     "Please enter a valid date and time" : "لطفاً یک تاریخ و زمان معتبر وارد کنید",
     "Global" : "عمومی",
     "Personal" : "شخصی",
+    "No more events today" : "هیچ رویداد دیگری برای امروز وجود ندارد",
+    "No upcoming events" : "رویداد پیش‌رویی وجود ندارد",
+    "Event does not exist" : "رویداد وجود ندارد",
     "Delete this occurrence" : "این رخداد را حذف کنید",
     "Delete this and all future" : "این و همه آینده را حذف کنید",
     "Details" : "جزئیات",
@@ -219,6 +226,7 @@ OC.L10N.register(
     "Close" : "بستن",
     "Show more details" : "جزئیات بیشتر را نشان دهید",
     "Subscribe to {name}" : "اشتراک در {name}",
+    "Export {name}" : "دریافت خروجی از {name}",
     "Anniversary" : "سالگرد",
     "Appointment" : "وقت ملاقات",
     "Business" : "کسب و کار",
@@ -266,15 +274,18 @@ OC.L10N.register(
     "Prev" : "مقدمه",
     "Next" : "بعدی",
     "Year" : "سال",
+    "No events to display" : "هیچ رویدادی برای نمایش وجود ندارد",
     "_+%n more_::_+%n more_" : ["+%n بیشتر","+%n بیشتر"],
-    "Other" : "اعلان‌ها",
+    "No events" : "رویدادی وجود ندارد",
+    "Create a new event or change the visible time-range" : "یک رویداد تازه بسازید یا بازه زمانی خود را تغییر بدهید",
+    "Other" : "دیگر",
     "When shared show" : "هنگام نمایش مشترک",
     "When shared show full event" : "هنگام اشتراک گذاری ، رویداد کامل را نشان می دهد",
     "When shared show only busy" : "وقتی نمایش اشتراکی فقط مشغول است",
     "When shared hide this event" : "هنگام اشتراک گذاری این رویداد را پنهان کنید",
     "The visibility of this event in shared calendars." : "قابلیت مشاهده این رویداد در تقویمهای مشترک.",
-    "Add a location" : "اضافه کردن یک محل",
-    "Add a description" : "توضیحات اضافه کنید",
+    "Add a location" : "افزودن یک محل",
+    "Add a description" : "یک توضیح بنویسید",
     "Status" : "وضعیت",
     "Confirmed" : "تایید شده",
     "Confirmation about the overall status of the event." : "تأیید درباره وضعیت کلی این رویداد.",
@@ -292,6 +303,7 @@ OC.L10N.register(
     "Relaxing" : "آرامش بخش",
     "Relax" : "آروم باش",
     "Commuting" : "رفت و آمد",
+    "Money" : "پول",
     "Presentation" : "ارائه",
     "Talk" : "گفتگو",
     "Camping" : "چادر زدن",
