@@ -6,6 +6,7 @@ OC.L10N.register(
     "Day" : "ថ្ងៃ",
     "Week" : "សប្ដាហ៍",
     "Month" : "ខែ",
+    "Copy link" : "ចម្លងតំណ",
     "Edit" : "កែប្រែ",
     "Delete" : "លុប",
     "Export" : "នាំចេញ",
@@ -35,6 +36,8 @@ OC.L10N.register(
     "Send email" : "ផ្ញើ​អ៊ីមែល",
     "Repeat" : "ធ្វើម្ដងទៀត",
     "never" : "មិនដែរ",
+    "first" : "ទីមួយ",
+    "last" : "ចុងក្រោយ",
     "More" : "ច្រើន​ទៀត",
     "Personal" : "ផ្ទាល់​ខ្លួន",
     "Details" : "ព័ត៌មាន​លម្អិត",
@@ -43,6 +46,7 @@ OC.L10N.register(
     "Daily" : "រាល់ថ្ងៃ",
     "Weekly" : "រាល់​សប្ដាហ៍",
     "Next" : "បន្ទាប់",
+    "Year" : "ឆ្នាំ",
     "Other" : "ផ្សេងៗ",
     "Mail" : "សំបុត្រ",
     "Birthday" : "ថ្ងៃ​កំណើត"
