@@ -3,23 +3,40 @@ OC.L10N.register(
     {
     "Cheers!" : "Prost!",
     "Calendar" : "Kalenner",
+    "New event" : "Neit Evenement",
     "Today" : "Haut",
     "Day" : "Dag",
     "Week" : "Woch",
     "Month" : "Mount",
+    "Copy link" : "Link kopéieren",
+    "Edit" : "Änneren",
     "Delete" : "Läschen",
+    "Export" : "Exportéieren",
     "Share link" : "Link deelen",
     "Share with users or groups" : "Mat Benotzer oder Gruppen deelen",
     "can edit" : "kann änneren",
     "New calendar" : "Neie Kalenner",
+    "Name" : "Numm",
+    "Deleted" : "Geläscht",
+    "Restore" : "Zrécksetzen",
+    "Delete permanently" : "Permanent läschen",
     "Cancel" : "Ofbriechen",
     "Automatic" : "Automatesch",
     "Actions" : "Aktiounen",
     "Location" : "Uert",
     "Description" : "Beschreiwung",
+    "to" : "bis",
+    "Add" : "Derbäimaachen",
     "Monday" : "Méindeg",
+    "Tuesday" : "Dënschdeg",
+    "Wednesday" : "Mëttwoch",
+    "Thursday" : "Donneschdeg",
+    "Friday" : "Freideg",
+    "Saturday" : "Samschdeg",
+    "Sunday" : "Sonndeg",
     "Save" : "Späicheren",
     "Update" : "Update",
+    "Your email address" : "Deng Email Adress",
     "Email" : "Email",
     "Unknown" : "Onbekannt",
     "Repeat" : "Widderhuelen",
@@ -34,9 +51,12 @@ OC.L10N.register(
     "Week {number} of {year}" : "Woch {Nummer} vum {Joer}",
     "Daily" : "All Dag",
     "Weekly" : "All Woch",
+    "Next" : "Weider",
+    "Other" : "Aner",
     "When shared show full event" : "Wann et gedeelt gouf, dann de ganzen Evenement uweisen",
     "When shared show only busy" : "Wann et gedeelt gouf, dann nëmmen als beschäftegt uweisen",
     "When shared hide this event" : "Wann et gedeelt gouf, dann verstopp dëst Evenement",
-    "Mail" : "Mail"
+    "Mail" : "Mail",
+    "Birthday" : "Gebuertsdag"
 },
 "nplurals=2; plural=(n != 1);");
