@@ -93,7 +93,6 @@ OC.L10N.register(
     "Unshare with {displayName}" : "Fjern deling med {displayName}",
     "An error occurred, unable to change the unshare the calendar." : "En feil oppstod, kan ikke endre fjerning av deling av kalenderen.",
     "An error occurred, unable to change the permission of the share." : "En feil oppstod, kan ikke endre rettighetene til delingen.",
-    "+ New calendar" : "+ Ny kalender",
     "New calendar" : "Ny kalender",
     "Name for new calendar" : "Navn på ny kalender",
     "Creating calendar …" : "Oppretter kalender ...",
@@ -103,14 +102,11 @@ OC.L10N.register(
     "An error occurred, unable to create the calendar." : "En feil oppstod, kunne ikke opprette kalenderen",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vennligst angi gyldig lenke (starte med http://, https://, webcal://, eller webcals://)",
     "Trash bin" : "Papirkurv",
-    "Loading deleted elements." : "Laster slettede elementer.",
-    "You do not have any deleted elements." : "Du har ingen slettede elementer.",
     "Name" : "Navn",
     "Deleted" : "Slettet",
     "Restore" : "Gjenopprett",
     "Delete permanently" : "Slett permanent",
     "Empty trash bin" : "Tøm papirkurv",
-    "Untitled element" : "Element uten tittel",
     "Unknown calendar" : "Ukjent kalender",
     "Could not load deleted calendars and objects" : "Kunne ikke laste slettede kalendere og objekter",
     "Could not restore calendar or event" : "Kunne ikke gjenopprette kalender eller hendelse",
@@ -376,6 +372,7 @@ OC.L10N.register(
     "Meditation" : "Meditasjon",
     "Relaxing" : "Avslapping",
     "Commuting" : "Pendler",
+    "Money" : "Penger",
     "Presentation" : "Presentasjon",
     "Talk" : "Samtale",
     "Camping" : "Camping",
