@@ -90,7 +90,6 @@ OC.L10N.register(
     "Unshare with {displayName}" : "Retrage cu {displayName}",
     "An error occurred, unable to change the unshare the calendar." : "A apărut o eroare, nu se poate schimba retragerea calendarului.",
     "An error occurred, unable to change the permission of the share." : "A apărut o eroare, nu se poate schimba permisiunile fişierelor partajate.",
-    "+ New calendar" : "+ Calendar nou",
     "New calendar" : "Calendar nou",
     "Name for new calendar" : "Numele noului calendar",
     "Creating calendar …" : "Se creează un calendar nou ...",
@@ -100,19 +99,15 @@ OC.L10N.register(
     "An error occurred, unable to create the calendar." : "A apărut o eroare, nu se poate creea acest calendar.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vă rugăm să introduceți un link valid (ce începe cu ttp://, https://, webcal://, sau webcals://)",
     "Trash bin" : "Coș de gunoi",
-    "Loading deleted elements." : "Se încarcă elementele șterse",
-    "You do not have any deleted elements." : "Nu ai elemente șterse",
     "Name" : "Nume",
     "Deleted" : "Șters",
     "Restore" : "Restaurare",
     "Delete permanently" : "Șterge permanent",
     "Empty trash bin" : "Golește coșul de gunoi",
-    "Untitled element" : "Element nedenumit",
     "Unknown calendar" : "Calendar necunoscut",
     "Could not load deleted calendars and objects" : "Nu s-au putut încărca obiectele și calendarele",
     "Could not restore calendar or event" : "Nu s-a putut restaura calendarul sau evenimentul",
     "Do you really want to empty the trash bin?" : "Doriti sigur sa goliți conținutul coșului de gunoi ?",
-    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Obiectele din coşul de gunoi sunt şterse dupa {numDays} zi","Obiectele din coşul de gunoi sunt şterse dupa {numDays} zile","Obiectele din coşul de gunoi sunt şterse dupa {numDays} de zile"],
     "Could not update calendar order." : "Nu s-a putut actualiza ordinea calendarului.",
     "Import calendars" : "Importă calendare",
     "Please select a calendar to import into …" : "Vă rugăm să selectaţi un calendar în care să importaţi ...",
